@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -29,15 +29,19 @@
 #include "gettext.h"
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
-#include <libgtkhtml/gtkhtml.h>
-#include <libgtkhtml/view/htmlselection.h>
-#include <libgtkhtml/layout/htmlbox.h>
-#include <libgtkhtml/layout/htmlboxtext.h>
+#include "libgtkhtml/gtkhtml.h"
+#include "libgtkhtml/view/htmlselection.h"
+#include "libgtkhtml/layout/htmlbox.h"
+#include "libgtkhtml/layout/htmlboxtext.h"
+#if USE_PRINTUNIX
+#include <gtk/gtkprintoperation.h>
+#include <gtk/gtkprintjob.h>
+#include <gtk/gtkprintunixdialog.h>
+#endif
 #include "common/claws.h"
 #include "common/version.h"
 #include "main.h"
 #include "plugin.h"
-#include "utils.h"
 #include "mimeview.h"
 #include "messageview.h"
 #include "prefs_common.h"
@@ -47,6 +51,10 @@
 #include "plugin.h"
 #include "menu.h"
 #include "defs.h"
+#include "utils.h"
+#include "alertpanel.h"
+#include "addr_compl.h"
+#include "printing.h"
 
 #ifdef USE_PTHREAD
 #include <pthread.h>
@@ -76,7 +84,12 @@ struct _GtkHtml2Viewer
 	GMutex		*mutex;
 	GtkWidget 	*link_popupmenu;
 	GtkItemFactory 	*link_popupfactory;
+	GtkWidget	*context_popupmenu;
+	GtkItemFactory 	*context_popupfactory;
+	gboolean	 is_on_url;
 	gint		 last_search_match;
+	gboolean	 preparing;
+	gboolean	 printing;
 };
 
 static MimeViewerFactory gtkhtml2_viewer_factory;
@@ -88,6 +101,9 @@ static void gtkhtml_open_uri_cb			(GtkHtml2Viewer *viewer,
 static void gtkhtml_copy_uri_cb			(GtkHtml2Viewer *viewer,
 						 guint		 action,
 						 void		*data);
+static void gtkhtml_zoom_cb			(GtkHtml2Viewer *viewer,
+						 guint		 action,
+						 void		*data);
 
 static GtkItemFactoryEntry gtkhtml_link_popup_entries[] = 
 {
@@ -95,6 +111,12 @@ static GtkItemFactoryEntry gtkhtml_link_popup_entries[] =
 	{N_("/Copy this _link"),	NULL, gtkhtml_copy_uri_cb, 0, NULL},
 };
 
+static GtkItemFactoryEntry gtkhtml_context_popup_entries[] = 
+{
+	{N_("/Zoom _in"),	NULL, gtkhtml_zoom_cb, 1, NULL},
+	{N_("/Zoom _out"),	NULL, gtkhtml_zoom_cb, 0, NULL},
+};
+
 static void scrolled_cb (GtkAdjustment *adj, GtkHtml2Viewer *viewer)
 {
 }
@@ -109,6 +131,111 @@ static GtkWidget *gtkhtml2_get_widget(MimeViewer *_viewer)
 	return GTK_WIDGET(viewer->scrollwin);
 }
 
+static gboolean found_in_addressbook(const gchar *address)
+{
+	gchar *addr = NULL;
+	gboolean found = FALSE;
+	gint num_addr = 0;
+	
+	if (!address)
+		return FALSE;
+	
+	addr = g_strdup(address);
+	extract_address(addr);
+	num_addr = complete_address(addr);
+	if (num_addr > 1) {
+		/* skip first item (this is the search string itself) */
+		int i = 1;
+		for (; i < num_addr && !found; i++) {
+			gchar *caddr = get_complete_address(i);
+			extract_address(caddr);
+			if (strcasecmp(caddr, addr) == 0)
+				found = TRUE;
+			g_free(caddr);
+		}
+	}
+	g_free(addr);
+	return found;
+}
+
+static gboolean load_images(GtkHtml2Viewer *viewer)
+{
+	MessageView *messageview = ((MimeViewer *)viewer)->mimeview 
+					? ((MimeViewer *)viewer)->mimeview->messageview 
+					: NULL;
+	MsgInfo *msginfo = NULL;
+	gchar *ab_folderpath = NULL;
+
+	if (messageview == NULL)
+		return FALSE;
+	
+	msginfo = messageview->msginfo;
+	
+	if (msginfo == NULL)
+		return FALSE;
+
+	/* don't load remote images, period. */
+	if (gtkhtml_prefs.local)
+		return FALSE;
+	
+	/* don't do whitelisting -> load images */
+	if (!gtkhtml_prefs.whitelist_ab)
+		return TRUE;
+
+	if (*gtkhtml_prefs.whitelist_ab_folder != '\0' &&
+	    strcasecmp(gtkhtml_prefs.whitelist_ab_folder, _("Any")) != 0)
+		ab_folderpath = gtkhtml_prefs.whitelist_ab_folder;
+
+	start_address_completion(ab_folderpath);
+
+	/* do whitelisting -> check sender */
+	if (found_in_addressbook(msginfo->from)) {
+		end_address_completion();
+		return TRUE;
+	}
+	
+	end_address_completion();
+	return FALSE;
+}
+
+static gboolean has_charset(FILE *fp)
+{
+	gchar buf[4096];
+	gint loaded = 0;
+	while ((loaded = fread(buf, 1, 4096, fp)) > 0) {
+		if (strcasestr(buf, "<meta") &&
+		    strcasestr(buf, "http-equiv") &&
+		    strcasestr(buf, "charset")) {
+			rewind(fp);
+			return TRUE;
+		}
+	}
+	rewind(fp);
+	return FALSE;
+}
+
+static gboolean has_header(FILE *fp)
+{
+	gchar buf[4096];
+	gint loaded = 0;
+	gboolean start = FALSE;
+	while ((loaded = fread(buf, 1, 4096, fp)) > 0) {
+		if (strcasestr(buf, "<head>")) {
+			start = TRUE;
+		}
+		if (strcasestr(buf, "</head>")) {
+			rewind(fp);
+			return (start == TRUE);
+		}
+		if (strcasestr(buf, "<body>")) {
+			rewind(fp);
+			return FALSE;
+		}
+	}
+	rewind(fp);
+	return FALSE;
+}
+
 static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 {
 	GtkHtml2Viewer *viewer = (GtkHtml2Viewer *) _viewer;
@@ -128,7 +255,7 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 	debug_print("gtkhtml2_show_mimepart\n");
 
 	if (viewer->filename != NULL) {
-		g_unlink(viewer->filename);
+		claws_unlink(viewer->filename);
 		g_free(viewer->filename);
 		viewer->filename = NULL;
 	}
@@ -147,6 +274,7 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 
 	html_view_zoom_reset(HTML_VIEW(viewer->html_view));
 	if (partinfo && !(procmime_get_part(viewer->filename, partinfo) < 0)) {
+		gboolean insert_in_header = FALSE, insert_all_header = FALSE;
 
 		if (_viewer && _viewer->mimeview &&
 		    _viewer->mimeview->messageview->forced_charset)
@@ -156,7 +284,7 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 		if (charset == NULL)
 			charset = conv_get_locale_charset_str();
 
-		debug_print("using charset %s\n", charset);
+		debug_print("using charset %s by default\n", charset);
 		
 		if (html_document_open_stream(viewer->html_doc, "text/html")) {
 			gboolean got_charset = FALSE;
@@ -167,31 +295,44 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 				goto out;
 			}
 
+			got_charset = has_charset(fp);
+			if (!got_charset) {
+				if (has_header(fp))
+					insert_in_header = TRUE;
+				else
+					insert_all_header = TRUE;
+			}
+
 			while ((loaded = fread(buf, 1, 4096, fp)) > 0) {
-				if (strcasestr(buf, "<meta") &&
-				    strcasestr(buf, "http-equiv") &&
-				    strcasestr(buf, "charset"))
-					got_charset = TRUE; /* hack */
-				
 				g_mutex_lock(viewer->mutex);
 				if (!viewer->stop_previous && !claws_is_exiting() && got_charset == FALSE) {
-					if (strcasestr(buf, "</head>")) {
+					if (insert_all_header) {
 						gchar *meta_charset = g_strdup_printf(
-							"<meta http-equiv=Content-Type content=\"text/html; charset=%s\">",
+							"<head><meta http-equiv=Content-Type content=\"text/html; charset=%s\"></head>",
 							charset);
 						html_document_write_stream(
 							viewer->html_doc, meta_charset, strlen(meta_charset));
 						debug_print("injected %s\n", meta_charset);
 						g_free(meta_charset);
 						got_charset = TRUE;
-					} else if (strcasestr(buf, "<body>")) {
+					} else if (insert_in_header && strcasestr(buf, "</head>")) {
+						gchar *start = NULL, *end = NULL;
 						gchar *meta_charset = g_strdup_printf(
-							"<head><meta http-equiv=Content-Type content=\"text/html; charset=%s\"></head>",
+							"<meta http-equiv=Content-Type content=\"text/html; charset=%s\">",
 							charset);
+						start = g_strdup(buf);
+						*(strcasestr(start, "</head>")) = '\0';
+						end = g_strdup(strcasestr(buf, "</head>"));
+						
+						html_document_write_stream(
+							viewer->html_doc, start, strlen(start));
 						html_document_write_stream(
 							viewer->html_doc, meta_charset, strlen(meta_charset));
-						debug_print("injected %s and head\n", meta_charset);
+						strncpy(buf, end, sizeof(buf));
+						debug_print("injected %s in head\n", meta_charset);
 						g_free(meta_charset);
+						g_free(start);
+						g_free(end);
 						got_charset = TRUE;
 					} 
 				}
@@ -218,6 +359,7 @@ out:
 	viewer->force_image_loading = FALSE;	
 	g_mutex_unlock(viewer->mutex);
 	messageview->updating = FALSE;
+	viewer->preparing = FALSE;
 	return FALSE;
 }
 
@@ -257,6 +399,7 @@ static void gtkhtml2_show_mimepart(MimeViewer *_viewer,
 	GtkHtml2Viewer *viewer = (GtkHtml2Viewer *) _viewer;
 	viewer->to_load = partinfo;
 	viewer->last_search_match = -1;
+	viewer->preparing = TRUE;
 	gtk_timeout_add(5, (GtkFunction)gtkhtml2_show_mimepart_prepare, viewer);
 }
 
@@ -273,7 +416,16 @@ static void gtkhtml2_clear_viewer(MimeViewer *_viewer)
 	GtkHtml2Viewer *viewer = (GtkHtml2Viewer *) _viewer;
 	GtkAdjustment *vadj;
 	
+	MessageView *messageview = ((MimeViewer *)viewer)->mimeview 
+					? ((MimeViewer *)viewer)->mimeview->messageview 
+					: NULL;
+
 	debug_print("gtkhtml2_clear_viewer\n");
+	if (messageview) {
+		NoticeView *noticeview = messageview->noticeview;
+		noticeview_hide(noticeview);
+	}
+
 	viewer->to_load = NULL;
 	if (!viewer->loading)
 		html_document_clear(viewer->html_doc);
@@ -292,7 +444,7 @@ static void gtkhtml2_destroy_viewer(MimeViewer *_viewer)
 
 	gtk_widget_unref(GTK_WIDGET(viewer->html_view));
 	gtk_widget_unref(GTK_WIDGET(viewer->scrollwin));
-	g_unlink(viewer->filename);
+	claws_unlink(viewer->filename);
 	g_free(viewer->filename);
     	g_free(viewer);
 }
@@ -338,7 +490,7 @@ static void gtkhtml_open_uri_cb (GtkHtml2Viewer *viewer, guint action, void *dat
 	gchar *uri = g_object_get_data(G_OBJECT(viewer->link_popupmenu),
 					   "uri");
 	g_object_set_data(G_OBJECT(viewer->link_popupmenu), "uri", NULL);
-	open_uri(uri, prefs_common.uri_cmd);
+	open_uri(uri, prefs_common_get_uri_cmd());
 	g_free(uri);
 }
 
@@ -376,9 +528,9 @@ void link_clicked(HtmlDocument *doc, const gchar *url, GtkHtml2Viewer *viewer) {
 
 	if (button == 1 || button == 2) {
 		if (real_url)
-			open_uri(real_url, prefs_common.uri_cmd);
+			open_uri(real_url, prefs_common_get_uri_cmd());
 		else
-			open_uri(url, prefs_common.uri_cmd);
+			open_uri(url, prefs_common_get_uri_cmd());
 	} else if (button == 3) {
 		g_object_set_data(G_OBJECT(viewer->link_popupmenu), "uri",
 			  real_url ? g_strdup(real_url):g_strdup(url));
@@ -410,10 +562,12 @@ static void on_url(GtkWidget *widget, const gchar *url, gpointer data)
 				   messageview->statusbar_cid, trimmed_uri);
 		g_free(real_url);
 		g_free(trimmed_uri);
+		((GtkHtml2Viewer *)viewer)->is_on_url = TRUE;
 	} else {
 		if (messageview->statusbar)
 			gtk_statusbar_pop(GTK_STATUSBAR(messageview->statusbar),
 				   messageview->statusbar_cid);
+		((GtkHtml2Viewer *)viewer)->is_on_url = FALSE;
 	}
 }
 
@@ -443,7 +597,7 @@ static void *gtkhtml_fetch_feed_threaded(void *arg)
 	if (f == NULL) {
 		perror("fdopen");
 		ctx->ready = TRUE;
-		g_unlink(template);
+		claws_unlink(template);
 		g_free(template);
 		return NULL;
 	}
@@ -453,7 +607,7 @@ static void *gtkhtml_fetch_feed_threaded(void *arg)
 	if (eh == NULL) {
 		g_warning("can't init curl");
 		ctx->ready = TRUE;
-		g_unlink(template);
+		claws_unlink(template);
 		g_free(template);
 		return NULL;
 	}
@@ -500,6 +654,7 @@ static void requested_url(HtmlDocument *doc, const gchar *url, HtmlStream *strea
 #ifdef HAVE_LIBCURL
 #ifdef USE_PTHREAD
 	pthread_t pt;
+	pthread_attr_t pta;
 #endif
 	GtkHtmlThreadCtx *ctx = NULL;
 	time_t start_time = time(NULL);
@@ -580,7 +735,7 @@ not_found_local:
 #ifdef HAVE_LIBCURL
 		real_url = NULL;
 		cache_file = NULL;
-                if (!viewer->force_image_loading && gtkhtml_prefs.local) {
+                if (!viewer->force_image_loading && !load_images(viewer)) {
 			remote_not_loaded = TRUE;
                         goto fail;
 		}
@@ -611,7 +766,9 @@ not_found_local:
 	        ctx->ready = FALSE;
 		debug_print("final URL: %s\n", ctx->url);
 #ifdef USE_PTHREAD
-	        if( pthread_create(&pt, PTHREAD_CREATE_JOINABLE, gtkhtml_fetch_feed_threaded,
+	        if (pthread_attr_init(&pta) != 0 ||
+		    pthread_attr_setdetachstate(&pta, PTHREAD_CREATE_JOINABLE) != 0 ||
+		    pthread_create(&pt, &pta, gtkhtml_fetch_feed_threaded,
 				        (void *)ctx) != 0 ) {
 		        /* Bummer, couldn't create thread. Continue non-threaded */
 		        tmpfile = gtkhtml_fetch_feed_threaded(ctx);
@@ -659,7 +816,8 @@ found_local:
 		FILE *fp = fopen(tmpfile, "r");
 		if (fp == NULL) {
 			html_stream_close(stream);
-			g_unlink(tmpfile);
+			claws_unlink(tmpfile);
+			g_free(tmpfile);
 #ifdef HAVE_LIBCURL
 			g_free(ctx);
 #endif
@@ -675,7 +833,8 @@ found_local:
 				gtk_main_iteration();
 		}
 		fclose(fp);
-		g_unlink(tmpfile);
+		claws_unlink(tmpfile);
+		g_free(tmpfile);
 	}
 #ifdef HAVE_LIBCURL
 	g_free(ctx);
@@ -690,7 +849,7 @@ fail:
 		if (messageview) {
 			gchar *text = NULL;
 			NoticeView *noticeview = messageview->noticeview;
-			if (gtkhtml_prefs.local) {
+			if (!load_images(viewer)) {
 				text = _("Remote images exist, but weren't loaded\naccording to your preferences.");
 			} else if (prefs_common.work_offline) {
 				text = _("Remote images exist, but weren't loaded\nbecause you are offline.");
@@ -908,6 +1067,147 @@ static gboolean htmlview_scrolled(GtkWidget *widget, GdkEventScroll *event,
 	return FALSE;
 }
 
+static void gtkhtml_zoom_cb (GtkHtml2Viewer *viewer, guint action, void *data)
+{
+	if (action == 1) {
+		html_view_zoom_in(HTML_VIEW(viewer->html_view));
+	} else {
+		html_view_zoom_out(HTML_VIEW(viewer->html_view));
+	}
+}
+
+static gboolean htmlview_btn_released(GtkWidget *widget, GdkEventButton *event,
+				    GtkHtml2Viewer *viewer)
+{
+	if (event->button == 3 && !viewer->is_on_url)
+		gtk_menu_popup(GTK_MENU(viewer->context_popupmenu), 
+		       NULL, NULL, NULL, NULL, 
+		       event->button, event->time);
+	return FALSE;
+}
+
+#if GTK_CHECK_VERSION(2,10,0) && USE_PRINTUNIX
+static void
+job_complete_cb (GtkPrintJob *print_job,
+		        GtkHtml2Viewer *viewer,
+		        GError *error)
+{
+	if (error) {
+		alertpanel_error(_("Printing failed:\n %s"), error->message);
+	}
+	viewer->printing = FALSE;
+}
+
+static void gtkhtml2_viewer_print(MimeViewer *mviewer)
+{
+	GtkHtml2Viewer *viewer = (GtkHtml2Viewer *)mviewer;
+	MainWindow *mainwin = mainwindow_get_mainwindow();
+	HtmlView *htmlview;
+	gchar *program = NULL, *cmd = NULL;
+	gchar *outfile = NULL;
+	gint result;
+	GError *error = NULL;
+	GtkWidget *dialog;
+	GtkPrintUnixDialog *print_dialog;
+	GtkPrinter *printer;
+	GtkPrintJob *job;
+
+	htmlview = HTML_VIEW(viewer->html_view);
+
+	gtk_widget_realize(viewer->html_view);
+	
+	while (viewer->preparing) {
+		claws_do_idle();
+	}
+	debug_print("Preparing print job...\n");
+
+	program = g_find_program_in_path("html2ps");
+
+	if (program == NULL) {
+		alertpanel_error(_("Printing HTML is only possible if the program 'html2ps' is installed."));
+		return;
+	}
+
+	if (viewer->filename == NULL) {
+		alertpanel_error(_("Filename is null."));
+		return;
+	}
+
+	outfile = get_tmp_file();
+	cmd = g_strdup_printf("%s%s -o %s %s", program, 
+			load_images(viewer)?"":" -T", 
+			outfile, viewer->filename);
+
+	g_free(program);
+
+	result = execute_command_line(cmd, FALSE);
+	g_free(cmd);
+
+	if (result != 0) {
+		alertpanel_error(_("Conversion to postscript failed."));
+		g_free(outfile);
+		return;
+	}
+
+	debug_print("Starting print job...\n");
+	
+	dialog = gtk_print_unix_dialog_new (_("Print"),
+		  	   	 mainwin? GTK_WINDOW (mainwin->window):NULL);
+	print_dialog = GTK_PRINT_UNIX_DIALOG (dialog);
+	gtk_print_unix_dialog_set_page_setup (print_dialog, printing_get_page_setup());
+	gtk_print_unix_dialog_set_settings (print_dialog, printing_get_settings());
+
+	gtk_print_unix_dialog_set_manual_capabilities(print_dialog,
+		GTK_PRINT_CAPABILITY_GENERATE_PS);
+
+	result = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_hide (dialog);
+
+	printer = gtk_print_unix_dialog_get_selected_printer (print_dialog);
+
+	if (result != GTK_RESPONSE_OK || !printer) {
+		gtk_widget_destroy (dialog);
+		g_free(outfile);
+		return;
+	}
+
+	if (!gtk_printer_accepts_ps(printer)) {
+		alertpanel_error(_("Printer %s doesn't accept PostScript files."), 
+			gtk_printer_get_name(printer));
+		g_free(outfile);
+		return;
+	}
+	
+	printing_store_settings(gtk_print_unix_dialog_get_settings(print_dialog));
+
+	job = gtk_print_job_new(viewer->filename,
+				printer,
+				printing_get_settings(),
+				printing_get_page_setup());
+
+	gtk_print_job_set_source_file(job, outfile, &error);
+
+	if (error) {
+		alertpanel_error(_("Printing failed:\n%s"), error->message);
+		g_error_free(error);
+		g_free(outfile);
+		return;
+	}
+	viewer->printing = TRUE;
+	
+	gtk_print_job_send (job,
+		(GtkPrintJobCompleteFunc) job_complete_cb,
+		viewer,
+		NULL);	
+
+	while (viewer->printing) {
+		claws_do_idle();
+	}
+
+	g_free(outfile);
+}
+#endif
+
 static MimeViewer *gtkhtml2_viewer_create(void)
 {
 	GtkHtml2Viewer *viewer;
@@ -917,6 +1217,8 @@ static MimeViewer *gtkhtml2_viewer_create(void)
 	gint n_entries;
 	GtkWidget *link_popupmenu;
 	GtkItemFactory *link_popupfactory;
+	GtkWidget *context_popupmenu;
+	GtkItemFactory *context_popupfactory;
 
 	debug_print("gtkhtml2_viewer_create\n");
 
@@ -930,7 +1232,9 @@ static MimeViewer *gtkhtml2_viewer_create(void)
 	viewer->mimeviewer.text_search = gtkhtml2_text_search;
 	viewer->mimeviewer.scroll_page = gtkhtml2_scroll_page;
 	viewer->mimeviewer.scroll_one_line = gtkhtml2_scroll_one_line;
-
+#if GTK_CHECK_VERSION(2,10,0) && USE_PRINTUNIX
+	viewer->mimeviewer.print = gtkhtml2_viewer_print;
+#endif
 	viewer->html_doc = html_document_new();
 	viewer->html_view = html_view_new();
 	viewer->scrollwin = gtk_scrolled_window_new(NULL, NULL);
@@ -983,6 +1287,8 @@ static MimeViewer *gtkhtml2_viewer_create(void)
 	g_signal_connect(G_OBJECT(viewer->html_view),"on_url", G_CALLBACK(on_url), viewer);
 	g_signal_connect(G_OBJECT(viewer->html_view), "scroll_event",
 			 G_CALLBACK(htmlview_scrolled), viewer);
+	g_signal_connect(G_OBJECT(viewer->html_view), "button_release_event",
+			 G_CALLBACK(htmlview_btn_released), viewer);
 
 	gtk_widget_show(GTK_WIDGET(viewer->scrollwin));
 	gtk_widget_ref(GTK_WIDGET(viewer->scrollwin));
@@ -996,6 +1302,15 @@ static MimeViewer *gtkhtml2_viewer_create(void)
 				      viewer);
 	viewer->link_popupmenu = link_popupmenu;
 	viewer->link_popupfactory = link_popupfactory;
+
+	n_entries = sizeof(gtkhtml_context_popup_entries) /
+		sizeof(gtkhtml_context_popup_entries[0]);
+	context_popupmenu = menu_create_items(gtkhtml_context_popup_entries, n_entries,
+				      "<UriPopupMenu>", &context_popupfactory,
+				      viewer);
+	viewer->context_popupmenu = context_popupmenu;
+	viewer->context_popupfactory = context_popupfactory;
+
 	viewer->filename = NULL;
 
 	return (MimeViewer *) viewer;
@@ -1032,7 +1347,7 @@ gint plugin_init(gchar **error)
 	gtkhtml2_viewer_tmpdir = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S,
 				"gtkhtml2_viewer", NULL);
 
-	if (!check_plugin_version(MAKE_NUMERIC_VERSION(2,9,2,72),
+	if (!check_plugin_version(MAKE_NUMERIC_VERSION(3,1,0,62),
 				VERSION_NUMERIC, _("GtkHtml2 HTML Viewer"), error))
 		return -1;
 
@@ -1086,7 +1401,7 @@ const gchar *plugin_type(void)
 
 const gchar *plugin_licence(void)
 {
-	return "GPL";
+	return "GPL3+";
 }
 
 const gchar *plugin_version(void)
