@@ -1,5 +1,5 @@
-/* Notification plugin for Claws-Mail
- * Copyright (C) 2005-2007 Holger Berndt
+/* Notification plugin for Claws Mail
+ * Copyright (C) 2005-2008 Holger Berndt
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,11 @@
 #include "gtk/gtkutils.h"
 
 #include "prefs_common.h"
+#include "mainwindow.h"
+#include "menu.h"
+#include "procmsg.h"
+#include "messageview.h"
+#include "compose.h"
 #include "gettext.h"
 
 #include "notification_core.h"
@@ -37,10 +42,7 @@ typedef struct {
 typedef struct {
   GtkWidget *window;
   GtkWidget *scrolled_win;
-  GtkWidget *event_box;
-  GtkWidget *color_ebox;
-  GtkWidget *hbox;
-  GtkWidget *entrybox;
+	GtkWidget *viewport;
 
   NotificationBannerEntry *entries;
   guint timeout_id;
@@ -56,18 +58,33 @@ typedef struct {
 static void       notification_banner_create(GSList*);
 static gboolean   scroller(gpointer data);
 static GtkWidget* create_entrybox(GSList*);
-static gboolean   notification_banner_move_press(GtkWidget*, GdkEventButton*,
-						 gpointer);
 static gboolean   notification_banner_configure(GtkWidget*, GdkEventConfigure*,
 						gpointer);
+static gboolean notification_banner_swap_colors(GtkWidget*,GdkEventCrossing*,gpointer);
+static gboolean notification_banner_button_press(GtkWidget*,GdkEventButton*,gpointer);
+static void notification_banner_show_popup(GtkWidget*,GdkEventButton*);
+static void notification_banner_popup_done(GtkMenuShell*,gpointer);
+
+static void banner_menu_reply_cb(gpointer, guint, GtkWidget*);
+
 
 static NotificationBanner banner;
 static ScrollingData      sdata;
 
+static GtkWidget *banner_popup;
+static GtkItemFactory *bannermenu_factory;
+static gboolean banner_popup_open = FALSE;
+
+static MsgInfo *current_msginfo = NULL;
+
 /* Corresponding mutexes */
 G_LOCK_DEFINE_STATIC(banner);
 G_LOCK_DEFINE_STATIC(sdata);
 
+static GtkItemFactoryEntry banner_menu_entries[] = {
+  {N_("/Reply"), NULL, banner_menu_reply_cb, 0, NULL},
+};
+
 
 void notification_banner_show(GSList *msg_list)
 {
@@ -104,83 +121,86 @@ void notification_banner_destroy(void)
 static void notification_banner_create(GSList *msg_list)
 {
   GtkRequisition requisition, requisition_after;
-  GdkColor bg;
+	GtkWidget *viewport;
+	GtkWidget *hbox;
+	GtkWidget *entrybox;
+	GdkColor bg;
+	gint n_entries;
+	gint banner_width;
 
   /* Window */
   if(!banner.window) {
+
     banner.window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "notification_banner");
     gtk_window_set_decorated(GTK_WINDOW(banner.window), FALSE);
-    gtk_widget_set_size_request(banner.window, gdk_screen_width(), -1);
+		if(notify_config.banner_width > 0)
+			gtk_widget_set_size_request(banner.window, notify_config.banner_width, -1);
+		else
+			gtk_widget_set_size_request(banner.window, gdk_screen_width(), -1);
     gtk_window_set_keep_above(GTK_WINDOW(banner.window), TRUE);
     gtk_window_set_accept_focus(GTK_WINDOW(banner.window), FALSE);
     gtk_window_set_skip_taskbar_hint(GTK_WINDOW(banner.window), TRUE);
     gtk_window_move(GTK_WINDOW(banner.window),
-		    notify_config.banner_root_x, notify_config.banner_root_y);
-    g_signal_connect(banner.window, "button-press-event",
-		     G_CALLBACK(notification_banner_move_press), NULL);
+										notify_config.banner_root_x, notify_config.banner_root_y);
     g_signal_connect(banner.window, "configure-event",
-		     G_CALLBACK(notification_banner_configure), NULL);
-
+										 G_CALLBACK(notification_banner_configure), NULL);
   }
   else {
     if(banner.entries) {
       g_free(banner.entries);
       banner.entries = NULL;
     }
-    gtk_widget_destroy(banner.event_box);
+    gtk_widget_destroy(banner.scrolled_win);
   }
   if(notify_config.banner_sticky)
     gtk_window_stick(GTK_WINDOW(banner.window));
   else
     gtk_window_unstick(GTK_WINDOW(banner.window));
 
-  /* Event box */
-  banner.event_box = gtk_event_box_new();
-  gtk_container_add(GTK_CONTAINER(banner.window), banner.event_box);
-
   /* Scrolled window */
   banner.scrolled_win = gtk_scrolled_window_new(NULL, NULL);
+  gtk_container_add(GTK_CONTAINER(banner.window), banner.scrolled_win);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(banner.scrolled_win),
-				 GTK_POLICY_NEVER, GTK_POLICY_NEVER);
-  gtk_container_add(GTK_CONTAINER(banner.event_box), banner.scrolled_win);
-
-  banner.color_ebox = gtk_event_box_new();
-  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW
-					(banner.scrolled_win),
-					banner.color_ebox);
+																 GTK_POLICY_NEVER, GTK_POLICY_NEVER);
 
+	/* Viewport */
+	viewport = gtk_viewport_new(NULL,NULL);
+	banner.viewport = viewport;
+	gtk_container_add(GTK_CONTAINER(banner.scrolled_win),viewport);
+	if(notify_config.banner_enable_colors) {
+		gtkut_convert_int_to_gdk_color(notify_config.banner_color_bg,&bg);
+		gtk_widget_modify_bg(viewport,GTK_STATE_NORMAL,&bg);
+	}
 
   /* Hbox */
-  banner.hbox = gtk_hbox_new(FALSE, 5);
-  gtk_container_add(GTK_CONTAINER(banner.color_ebox), banner.hbox);
+  hbox = gtk_hbox_new(FALSE, 5);
+	gtk_container_add(GTK_CONTAINER(viewport),hbox);
 
   /* Entrybox */
-  banner.entrybox = create_entrybox(msg_list);
-  gtk_box_pack_start(GTK_BOX(banner.hbox), banner.entrybox, FALSE, FALSE, 0);
+  entrybox = create_entrybox(msg_list);
+  gtk_box_pack_start(GTK_BOX(hbox), entrybox, FALSE, FALSE, 0);
 
-  /* Color */
-  if(notify_config.banner_enable_colors) {
-    gtkut_convert_int_to_gdk_color(notify_config.banner_color_bg,&bg);
-    gtk_widget_modify_bg(banner.color_ebox,GTK_STATE_NORMAL,&bg);
-  }
-  
   gtk_widget_show_all(banner.window);
 
   /* Scrolling */
-  gtk_widget_size_request(banner.hbox, &requisition);
-  if(requisition.width > gdk_screen_width()) {
+  gtk_widget_size_request(hbox, &requisition);
+  if(notify_config.banner_width > 0)
+		banner_width = notify_config.banner_width;
+	else
+		banner_width = gdk_screen_width();
+  if(requisition.width > banner_width) {
     /* Line is too big for screen! */
     /* Double the entrybox into hbox */
     GtkWidget *separator, *second_entrybox;
 
     separator = gtk_vseparator_new();
-    gtk_box_pack_start(GTK_BOX(banner.hbox), separator,
+    gtk_box_pack_start(GTK_BOX(hbox), separator,
 		       FALSE, FALSE, 0);
     second_entrybox = create_entrybox(msg_list);
-    gtk_box_pack_start(GTK_BOX(banner.hbox), second_entrybox, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(hbox), second_entrybox, FALSE, FALSE, 0);
 
     gtk_widget_show_all(banner.window);
-    gtk_widget_size_request(banner.hbox, &requisition_after);
+    gtk_widget_size_request(hbox, &requisition_after);
 
     G_LOCK(sdata);
     sdata.banner_width = requisition_after.width - requisition.width;
@@ -208,27 +228,15 @@ static void notification_banner_create(GSList *msg_list)
     sdata.adj = NULL;
     G_UNLOCK(sdata);
   }
-}
 
-static gboolean notification_banner_move_press(GtkWidget *widget,
-					       GdkEventButton *event,
-					       gpointer data)
-{
-  if(event->type == GDK_BUTTON_PRESS) {
-    if(event->button == 1) {
-      gtk_window_begin_move_drag(GTK_WINDOW(gtk_widget_get_toplevel(widget)), 
-				 event->button, event->x_root, event->y_root,
-				 event->time);
-    }
-    else if(event->button == 2) {
-      gint pos_x, pos_y;
-      gtk_window_get_position(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
-			      &pos_x, &pos_y);
-      gtk_window_move(GTK_WINDOW(gtk_widget_get_toplevel(widget)), 0, pos_y);
-    }
-  }
-
-  return TRUE;
+	/* menu */
+  n_entries = sizeof(banner_menu_entries) /
+    sizeof(banner_menu_entries[0]);
+  banner_popup = menu_create_items(banner_menu_entries,
+																	 n_entries, "<BannerMenu>", &bannermenu_factory,
+																	 NULL);
+	g_signal_connect(banner_popup,"selection-done",
+									 G_CALLBACK(notification_banner_popup_done), NULL);
 }
 
 static gboolean notification_banner_configure(GtkWidget *widget,
@@ -243,13 +251,22 @@ static gboolean notification_banner_configure(GtkWidget *widget,
 
 static gboolean scroller(gpointer data)
 {
+	// don't scroll during popup open
+	if(banner_popup_open)
+		return banner.scrolling;
+
   G_LOCK(sdata);
+	while(gtk_events_pending())
+		gtk_main_iteration();
   if(sdata.adj && GTK_IS_ADJUSTMENT(sdata.adj)) {
     if(sdata.adj->value != sdata.banner_width)
       gtk_adjustment_set_value(sdata.adj, sdata.adj->value + 1);
     else
       gtk_adjustment_set_value(sdata.adj, 0);
+		gtk_adjustment_value_changed(sdata.adj);
   }
+	while(gtk_events_pending())
+		gtk_main_iteration();
   G_UNLOCK(sdata);
   return banner.scrolling;
 }
@@ -258,10 +275,16 @@ static GtkWidget* create_entrybox(GSList *msg_list)
 {
   GtkWidget *entrybox;
   GdkColor fg;
+	GdkColor bg;
   gint list_length;
 
   list_length = g_slist_length(msg_list);
 
+  if(notify_config.banner_enable_colors) {
+    gtkut_convert_int_to_gdk_color(notify_config.banner_color_bg,&bg);
+		gtkut_convert_int_to_gdk_color(notify_config.banner_color_fg,&fg);
+  }
+
   if(banner.entries) {
     g_free(banner.entries);
     banner.entries = NULL;
@@ -273,22 +296,41 @@ static GtkWidget* create_entrybox(GSList *msg_list)
     gint ii = 0;
     banner.entries = g_new(NotificationBannerEntry, list_length);
     for(walk = msg_list; walk != NULL; walk = g_slist_next(walk)) {
-      CollectedMsg *cmsg = walk->data;
       GtkWidget *label1;
       GtkWidget *label2;
       GtkWidget *label3;
       GtkWidget *label4;
       GtkWidget *label5;
       GtkWidget *label6;
+			GtkWidget *ebox;
+      CollectedMsg *cmsg = walk->data;
       
       if(ii > 0) {
-	GtkWidget *separator;
-	separator = gtk_vseparator_new();
-	gtk_box_pack_start(GTK_BOX(entrybox), separator,
-			   FALSE, FALSE, 0);
+				GtkWidget *separator;
+				separator = gtk_vseparator_new();
+				gtk_box_pack_start(GTK_BOX(entrybox), separator, FALSE, FALSE, 0);
       }
 
+			ebox = gtk_event_box_new();
+			gtk_box_pack_start(GTK_BOX(entrybox), ebox, FALSE, FALSE, 0);
+			gtk_widget_set_events(ebox,
+														GDK_POINTER_MOTION_MASK |
+														GDK_BUTTON_PRESS_MASK);
+
+			if(notify_config.banner_enable_colors)
+				gtk_widget_modify_bg(ebox,GTK_STATE_NORMAL,&bg);
+
       banner.entries[ii].table = gtk_table_new(3, 2, FALSE);
+			gtk_container_add(GTK_CONTAINER(ebox),banner.entries[ii].table);
+			g_signal_connect(ebox, "enter-notify-event",
+											 G_CALLBACK(notification_banner_swap_colors),
+											 banner.entries[ii].table);
+			g_signal_connect(ebox, "leave-notify-event",
+											 G_CALLBACK(notification_banner_swap_colors),
+											 banner.entries[ii].table);
+			g_signal_connect(ebox, "button-press-event",
+											 G_CALLBACK(notification_banner_button_press),
+											 cmsg);
 
       label1 = gtk_label_new(prefs_common_translated_header_name("From:"));
       gtk_misc_set_alignment(GTK_MISC(label1), 0, 0.5);
@@ -316,17 +358,15 @@ static GtkWidget* create_entrybox(GSList *msg_list)
       gtk_table_attach_defaults(GTK_TABLE(banner.entries[ii].table),
 				label6, 1, 2, 2, 3);
       gtk_table_set_col_spacings(GTK_TABLE(banner.entries[ii].table), 5);
-      gtk_box_pack_start(GTK_BOX(entrybox), banner.entries[ii++].table,
-			 FALSE, FALSE, 0);
+			ii++;
       /* Color */
       if(notify_config.banner_enable_colors) {
-	gtkut_convert_int_to_gdk_color(notify_config.banner_color_fg,&fg);
-	gtk_widget_modify_fg(label1,GTK_STATE_NORMAL,&fg);
-	gtk_widget_modify_fg(label2,GTK_STATE_NORMAL,&fg);
-	gtk_widget_modify_fg(label3,GTK_STATE_NORMAL,&fg);
-	gtk_widget_modify_fg(label4,GTK_STATE_NORMAL,&fg);
-	gtk_widget_modify_fg(label5,GTK_STATE_NORMAL,&fg);
-	gtk_widget_modify_fg(label6,GTK_STATE_NORMAL,&fg);
+				gtk_widget_modify_fg(label1,GTK_STATE_NORMAL,&fg);
+				gtk_widget_modify_fg(label2,GTK_STATE_NORMAL,&fg);
+				gtk_widget_modify_fg(label3,GTK_STATE_NORMAL,&fg);
+				gtk_widget_modify_fg(label4,GTK_STATE_NORMAL,&fg);
+				gtk_widget_modify_fg(label5,GTK_STATE_NORMAL,&fg);
+				gtk_widget_modify_fg(label6,GTK_STATE_NORMAL,&fg);
       }
     }
   }
@@ -351,4 +391,108 @@ static GtkWidget* create_entrybox(GSList *msg_list)
   return entrybox;
 }
 
+static gboolean notification_banner_swap_colors(GtkWidget *widget,
+																								GdkEventCrossing *event,
+																								gpointer data)
+{
+	GList *children;
+	GList *walk;
+	GdkColor *old_bg;
+	
+	children = gtk_container_get_children(GTK_CONTAINER(data));
+
+	old_bg = gdk_color_copy(&(gtk_widget_get_style(widget)->bg[GTK_STATE_NORMAL]));
+	if(children)
+		gtk_widget_modify_bg(widget,GTK_STATE_NORMAL,
+												 &(gtk_widget_get_style(GTK_WIDGET(children->data))->fg[GTK_STATE_NORMAL]));
+	
+	for(walk = children; walk; walk = walk->next)
+		gtk_widget_modify_fg(GTK_WIDGET(walk->data),GTK_STATE_NORMAL,old_bg);
+	
+	g_list_free(children);
+	gdk_color_free(old_bg);
+	return FALSE;
+}
+
+static gboolean notification_banner_button_press(GtkWidget *widget,
+																								 GdkEventButton *button,
+																								 gpointer data)
+{
+	gboolean done;
+	done = FALSE;
+	if(button->type == GDK_BUTTON_PRESS) {
+		CollectedMsg *cmsg = (CollectedMsg*) data;
+    if(button->button == 1) {
+			/* jump to that message */
+			if(cmsg->msginfo) {
+				gchar *path;
+				path = procmsg_get_message_file_path(cmsg->msginfo);
+				mainwindow_jump_to(path, TRUE);
+				g_free(path);
+			}
+			done = TRUE;
+		}
+		else if(button->button == 2) {
+      gtk_window_begin_move_drag(GTK_WINDOW(gtk_widget_get_toplevel(widget)), 
+																 button->button, button->x_root, button->y_root,
+																 button->time);
+		}
+		else if(button->button == 3) {
+			current_msginfo = cmsg->msginfo;
+			notification_banner_show_popup(widget, button);
+			banner_popup_open = TRUE;
+			done = TRUE;
+		}
+	}
+	return done;
+}
+
+static void notification_banner_show_popup(GtkWidget *widget,
+																					 GdkEventButton *event)
+{
+  int button, event_time;
+
+  if(event) {
+		button = event->button;
+		event_time = event->time;
+	}
+  else {
+		button = 0;
+		event_time = gtk_get_current_event_time();
+	}
+
+  gtk_menu_popup(GTK_MENU(banner_popup), NULL, NULL, NULL, NULL,
+								 button, event_time);
+}
+
+static void notification_banner_popup_done(GtkMenuShell *menushell,
+																					 gpointer      user_data)
+{
+	current_msginfo = NULL;
+	banner_popup_open = FALSE;
+}
+
+static void banner_menu_reply_cb(gpointer data,
+																 guint action,
+																 GtkWidget *widget)
+{
+	MainWindow *mainwin;
+	MessageView *messageview;
+	GSList *msginfo_list = NULL;
+
+	if(!(mainwin = mainwindow_get_mainwindow()))
+		return;
+
+	if(!(messageview = (MessageView*)mainwin->messageview))
+		return;
+
+	g_return_if_fail(current_msginfo);
+
+	msginfo_list = g_slist_prepend(msginfo_list, current_msginfo);
+	compose_reply_from_messageview(messageview, msginfo_list,
+																 prefs_common.reply_with_quote ?
+																 COMPOSE_REPLY_WITH_QUOTE : COMPOSE_REPLY_WITHOUT_QUOTE);
+  g_slist_free(msginfo_list);
+}
+
 #endif /* NOTIFICATION_BANNER */
