@@ -18,13 +18,16 @@
 #ifndef NOTIFICATION_CORE_H
 #define NOTIFICATION_CORE_H NOTIFICATION_CORE_H
 
+#include "mainwindow.h"
 #include "folder.h"
+#include "procmsg.h"
 
 typedef struct {
   gchar *from;
   gchar *subject;
   FolderItem *folder_item;
   gchar *folderitem_name;
+	MsgInfo *msginfo;
 } CollectedMsg;
 
 typedef enum {
@@ -56,6 +59,7 @@ void     notification_new_unnotified_msgs(FolderItemUpdateData*);
 gboolean notification_notified_hash_msginfo_update(MsgInfoUpdate*);
 void     notification_notified_hash_startup_init(void);
 
+void     notification_show_mainwindow(MainWindow *mainwin);
 /* folder type specific settings */
 gboolean notify_include_folder_type(FolderType, gchar*);
 
