@@ -1,9 +1,9 @@
-/* Notification Plugin for Claws Mail
- * Copyright (C) 2005-2006 Holger Berndt
+/* Notification plugin for Claws-Mail
+ * Copyright (C) 2005-2007 Holger Berndt
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* This code is based on foldersel.c in Claws Mail.
@@ -29,6 +28,7 @@
 
 /* System includes */
 #include <string.h>
+#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
 /* Claws Mail includes */
@@ -40,6 +40,7 @@
 #include "common/prefs.h"
 #include "common/xml.h"
 #include "common/hooks.h"
+#include "prefs_common.h"
 
 #include "gettext.h"
 
@@ -114,6 +115,7 @@ static gboolean foldercheck_foreach_update_to_list(GtkTreeModel*, GtkTreePath*,
 						   GtkTreeIter*, gpointer);
 static gchar *foldercheck_get_array_path(void);
 static gboolean my_folder_update_hook(gpointer, gpointer);
+static gboolean key_pressed(GtkWidget*, GdkEventKey*,gpointer);
 
 
 /* Creates an entry in the specific_folder_array, and fills it with a new
@@ -480,6 +482,8 @@ static void foldercheck_create_window(SpecificFolderArrayEntry *entry)
     (GTK_WINDOW(entry->window), "folder_selection", "Claws Mail");  
   g_signal_connect(G_OBJECT(entry->window), "delete_event",
 		   G_CALLBACK(delete_event), entry);
+  g_signal_connect(G_OBJECT(entry->window), "key_press_event",
+      G_CALLBACK(key_pressed), entry);
   MANAGE_WINDOW_SIGNALS_CONNECT(entry->window);
 
   /* vbox */
@@ -517,6 +521,10 @@ static void foldercheck_create_window(SpecificFolderArrayEntry *entry)
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(entry->treeview), FALSE);
   gtk_tree_view_set_search_column(GTK_TREE_VIEW(entry->treeview),
 				  FOLDERCHECK_FOLDERNAME);
+  gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(entry->treeview),
+				  prefs_common.use_stripes_everywhere);
+  gtk_tree_view_set_enable_tree_lines(GTK_TREE_VIEW(entry->treeview),
+				  prefs_common.enable_dotted_lines);
 
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(entry->treeview));
   gtk_tree_selection_set_mode(selection, GTK_SELECTION_BROWSE);
@@ -856,6 +864,8 @@ static void folder_toggle_cb(GtkCellRendererToggle *cell_renderer,
 				 FOLDERCHECK_CHECK,toggle_item);
   }
 
+  while(gtk_events_pending())
+    gtk_main_iteration();
 }
 
 /* Helper function for folder_toggle_cb */
@@ -972,3 +982,12 @@ static gboolean my_folder_update_hook(gpointer source, gpointer data)
 
   return FALSE;
 }
+
+static gboolean key_pressed(GtkWidget *widget, GdkEventKey *event, gpointer data)
+{
+  if(event && (event->keyval == GDK_Escape)) {
+    foldercheck_cancel(NULL, data);
+    return TRUE;
+  }
+  return FALSE;
+}
