@@ -42,7 +42,6 @@
 
 static GdkPixbuf* notification_trayicon_create(void);
 
-static void notification_trayicon_on_activate(GtkStatusIcon*, gpointer);
 static void notification_trayicon_on_popup_menu(GtkStatusIcon*,guint,
 						guint,gpointer);
 static gboolean notification_trayicon_on_size_changed(GtkStatusIcon*,
@@ -384,8 +383,8 @@ static GdkPixbuf* notification_trayicon_create(void)
 }
 
 /* Hide/show main window */
-static void notification_trayicon_on_activate(GtkStatusIcon *status_icon,
-					      gpointer user_data)
+void notification_trayicon_on_activate(GtkStatusIcon *status_icon,
+																			 gpointer user_data)
 {
   MainWindow *mainwin;
   if((mainwin = mainwindow_get_mainwindow()) == NULL)
@@ -394,20 +393,14 @@ static void notification_trayicon_on_activate(GtkStatusIcon *status_icon,
   if(GTK_WIDGET_VISIBLE(GTK_WIDGET(mainwin->window))) {
     if((gdk_window_get_state(GTK_WIDGET(mainwin->window)->window)&GDK_WINDOW_STATE_ICONIFIED)
        || mainwindow_is_obscured()) {
-      gtk_window_deiconify(GTK_WINDOW(mainwin->window));
-      gtk_window_set_skip_taskbar_hint(GTK_WINDOW(mainwin->window), FALSE);
-      main_window_show(mainwin);
-      gtk_window_present(GTK_WINDOW(mainwin->window));
+      notification_show_mainwindow(mainwin);
     }
     else {
       main_window_hide(mainwin);
     }
   }
   else {
-    gtk_window_deiconify(GTK_WINDOW(mainwin->window));
-    gtk_window_set_skip_taskbar_hint(GTK_WINDOW(mainwin->window), FALSE);
-    main_window_show(mainwin);
-    gtk_window_present(GTK_WINDOW(mainwin->window));
+    notification_show_mainwindow(mainwin);
   }
 }
 
@@ -740,10 +733,7 @@ static void notification_trayicon_popup_default_action_cb(NotifyNotification
     NotificationFolderType nftype;
 
     /* Let mainwindow pop up */
-    gtk_window_deiconify(GTK_WINDOW(mainwin->window));
-    gtk_window_set_skip_taskbar_hint(GTK_WINDOW(mainwin->window), FALSE);
-    main_window_show(mainwin);
-    gtk_window_present(GTK_WINDOW(mainwin->window));
+    notification_show_mainwindow(mainwin);
     /* If there is only one new mail message, jump to this message */
     nftype = (NotificationFolderType)GPOINTER_TO_INT(user_data);
     if((popup.count == 1) && (nftype == F_TYPE_MAIL)) {
@@ -902,4 +892,18 @@ static gchar* notification_trayicon_popup_assemble_body(MsgInfo *msginfo)
 
 #endif /* HAVE_LIBNOTIFY */
 
+gboolean notification_trayicon_is_available(void)
+{
+	gboolean is_available;
+	is_available = FALSE;
+
+	if(trayicon) {
+		if(gtk_status_icon_is_embedded(trayicon) &&
+			 gtk_status_icon_get_visible(trayicon))
+			is_available = TRUE;
+	}
+
+	return is_available;
+}
+
 #endif /* NOTIFICATION_TRAYICON */
