@@ -1,14 +1,13 @@
-/*
- * perl_plugin -- Perl Support for Claws Mail
+/* Perl plugin -- Perl Support for Claws Mail
  *
- * Copyright (C) 2004-2005   Holger Berndt
+ * Copyright (C) 2004-2007 Holger Berndt
  *
- * Sylpheed is a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2005 Hiroyuki Yamamoto and the Claws Mail Team
+ * Sylpheed and Claws-Mail are GTK+ based, lightweight, and fast e-mail clients
+ * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,8 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,9 +24,6 @@
 #endif
 #include "pluginconfig.h"
 
-#include <glib.h>
-#include <glib/gi18n.h>
-
 #include "common/version.h"
 #include "common/defs.h"
 #include "common/utils.h"
@@ -49,16 +44,23 @@
 #include "log.h"
 #include "plugin.h"
 
+#include <EXTERN.h>
+#include <perl.h>
+#include <XSUB.h>
+
+#ifdef _
+# undef _
+#endif
+
+#include <glib.h>
+#include <glib/gi18n.h>
+
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <unistd.h>
 
-#include <EXTERN.h>
-#include <perl.h>
-#include <XSUB.h>
-
 #include "pluginconfig.h"
 #include "perl_plugin.h"
 #include "perl_gtk.h"
@@ -1416,15 +1418,15 @@ static int perl_load_file(void)
     if(val == G_ALERTOTHER) {
       /* Open PERLFILTER in an external editor */
       perlfilter = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, PERLFILTER, NULL);
-      if (prefs_common.ext_editor_cmd &&
-	  (pp = strchr(prefs_common.ext_editor_cmd, '%')) &&
+      if (prefs_common_get_ext_editor_cmd() &&
+	  (pp = strchr(prefs_common_get_ext_editor_cmd(), '%')) &&
 	  *(pp + 1) == 's' && !strchr(pp + 2, '%')) {
-	g_snprintf(buf, sizeof(buf), prefs_common.ext_editor_cmd, perlfilter);
+	g_snprintf(buf, sizeof(buf), prefs_common_get_ext_editor_cmd(), perlfilter);
       }
       else {
-	if (prefs_common.ext_editor_cmd)
+	if (prefs_common_get_ext_editor_cmd())
 	  g_warning("Perl Plugin: External editor command line is invalid: `%s'",
-		    prefs_common.ext_editor_cmd);
+		    prefs_common_get_ext_editor_cmd());
 	g_snprintf(buf, sizeof(buf), "emacs %s", perlfilter);
       }
       g_free(perlfilter);
@@ -2011,9 +2013,11 @@ static void perl_plugin_save_config(void)
     prefs_file_close_revert(pfile);
     return;
   }
-  fprintf(pfile->fp, "\n");
-
-  prefs_file_close(pfile);
+        if (fprintf(pfile->fp, "\n") < 0) {
+		FILE_OP_ERROR(rcpath, "fprintf");
+		prefs_file_close_revert(pfile);
+	} else
+	        prefs_file_close(pfile);
 }
 
 gint plugin_init(gchar **error)
@@ -2031,7 +2035,7 @@ gint plugin_init(gchar **error)
   *env  = NULL;
 
   /* version check */
-	if(!check_plugin_version(MAKE_NUMERIC_VERSION(2,9,2,72),
+	if(!check_plugin_version(MAKE_NUMERIC_VERSION(3,1,0,14),
 				VERSION_NUMERIC, "Perl", error))
 		return -1;
 
@@ -2135,7 +2139,7 @@ const gchar *plugin_type(void)
 
 const gchar *plugin_licence(void)
 {
-  return "GPL";
+  return "GPL3+";
 }
 
 const gchar *plugin_version(void)
