@@ -78,7 +78,7 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 	CURLcode res;
 	time_t last_modified;
 	gchar *time_str = NULL;
-	gint response_code;
+	long response_code;
 
 	gchar *template = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, RSSYL_DIR,
 			G_DIR_SEPARATOR_S, RSSYL_TMP_TEMPLATE, NULL);
@@ -101,7 +101,7 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 	if (f == NULL) {
 		perror("fdopen");
 		ctx->error = g_strdup(_("Cannot open temporary file"));
-		g_unlink(template);
+		claws_unlink(template);
 		g_free(template);
 		ctx->ready = TRUE;
 		return NULL;
@@ -113,7 +113,7 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 		g_warning("can't init curl");
 		ctx->error = g_strdup(_("Cannot init libCURL"));
 		fclose(f);
-		g_unlink(template);
+		claws_unlink(template);
 		g_free(template);
 		ctx->ready = TRUE;
 		return NULL;
@@ -170,7 +170,7 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 		ctx->ready = TRUE;
 		curl_easy_cleanup(eh);
 		fclose(f);
-		g_unlink(template);
+		claws_unlink(template);
 		g_free(template);
 		return NULL;
 	}
@@ -214,7 +214,7 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 				break;
 		}
 		ctx->ready = TRUE;
-		g_unlink(template);
+		claws_unlink(template);
 		g_free(template);
 		return NULL;
 	}
@@ -223,7 +223,7 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 		if( response_code == 304 ) {
 			debug_print("RSSyl: don't rely on server response 304, defer modified "
 					"check\n");
-			g_unlink(template);
+			claws_unlink(template);
 			g_free(template);
 			ctx->defer_modified_check = TRUE;
 			template = rssyl_fetch_feed_threaded(ctx);
@@ -322,7 +322,7 @@ xmlDocPtr rssyl_fetch_feed(const gchar *url, time_t last_update, gchar **title,
 	doc = xmlParseFile(template);
 
 	if( doc == NULL ) {
-		g_unlink(template);
+		claws_unlink(template);
 		g_free(template);
 		g_warning("Couldn't fetch feed '%s', aborting.\n", url);
 		log_error(LOG_PROTOCOL, RSSYL_LOG_ERROR_FETCH, url);
@@ -354,7 +354,7 @@ xmlDocPtr rssyl_fetch_feed(const gchar *url, time_t last_update, gchar **title,
 	g_free(tmptitle);
 #endif	/* RSSYL_DEBUG */
 
-	g_unlink(template);
+	claws_unlink(template);
 	g_free(template);
 
 	debug_print("RSSyl: XML - root node is '%s'\n", node->name);
@@ -1078,7 +1078,7 @@ gboolean rssyl_add_feed_item(RSSylFolderItem *ritem, RSSylFeedItem *fitem)
 	gint d = -1, fd, dif = 0;
 	FILE *f;
 	RSSylFeedItem *oldfitem = NULL;
-	gchar *meta_charset = NULL;
+	gchar *meta_charset = NULL, *url_html = NULL;
 	gboolean err = FALSE;
 
 	g_return_val_if_fail(ritem != NULL, FALSE);
@@ -1179,23 +1179,26 @@ gboolean rssyl_add_feed_item(RSSylFolderItem *ritem, RSSylFeedItem *fitem)
 	}
 
 	if( tmpurl )
-		err |= (fprintf(f, "<p>URL: <a href=\"%s\">%s</a></p>\n<br>\n",
-				tmpurl, tmpurl) < 0);
+		url_html = g_strdup_printf("<p>URL: <a href=\"%s\">%s</a></p>\n<br>\n",
+				tmpurl, tmpurl);
 
-	if( fitem->text )
-		err |= (fprintf(f, "<html><head>"
-				"%s\n"
-				"<base href=\"%s\">\n"
-			        "</head><body>\n"
-				RSSYL_TEXT_START"\n"
-				"%s%s"
-				RSSYL_TEXT_END"\n\n",
-				meta_charset ? meta_charset:"",
-				fitem->link,
-				fitem->text, (fitem->text ? "\n" : "") ) < 0);
+	err |= (fprintf(f, "<html><head>"
+			"%s\n"
+			"<base href=\"%s\">\n"
+			"</head><body>\n"
+			"%s"
+			RSSYL_TEXT_START"\n"
+			"%s%s"
+			RSSYL_TEXT_END"\n\n",
+
+			meta_charset ? meta_charset:"",
+			fitem->link,
+			url_html?url_html:"",
+			(fitem->text ? fitem->text : ""),
+			(fitem->text ? "\n" : "") ) < 0 );
 
 	g_free(meta_charset);
-
+	g_free(url_html);	
 	if( fitem->media ) {
 		if( fitem->media->size > 0 ) {
 			tmpid = g_strdup_printf(ngettext("%ld byte", "%ld bytes",
@@ -1510,7 +1513,7 @@ FolderItem *rssyl_subscribe_new_feed(FolderItem *parent, const gchar *url,
 	main_window_cursor_wait(mainwindow_get_mainwindow());
 	doc = rssyl_fetch_feed(myurl, -1, &title, &error);
 	main_window_cursor_normal(mainwindow_get_mainwindow());
-	if( !title ) {
+	if( !doc || !title ) {
 		if (verbose) {
 			gchar *tmp;
 			tmp = g_markup_printf_escaped(_("Couldn't fetch URL '%s':\n%s"),
@@ -1521,6 +1524,7 @@ FolderItem *rssyl_subscribe_new_feed(FolderItem *parent, const gchar *url,
 			log_error(LOG_PROTOCOL, _("Couldn't fetch URL '%s':\n%s\n"), myurl, error ? error:_("Unknown error"));
 		g_free(myurl);
 		g_free(error);
+		xmlFreeDoc(doc);
 		return NULL;
 	}
 	g_free(error);
@@ -1534,6 +1538,7 @@ FolderItem *rssyl_subscribe_new_feed(FolderItem *parent, const gchar *url,
 			g_free(tmp);
 		}
 		g_free(myurl);
+		xmlFreeDoc(doc);
 		return NULL;
 	}
 
