@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -26,7 +26,6 @@
 #include <sys/stat.h>
 #include "gettext.h"
 #include <ical.h>
-#include "utils.h"
 #include "vcalendar.h"
 #include "vcal_folder.h"
 #include "vcal_manager.h"
@@ -37,22 +36,15 @@
 #include "prefs.h"
 #include "prefs_common.h"
 #include "prefs_account.h"
+#include "alertpanel.h"
 #include "account.h"
 #include "codeconv.h"
 #include <time.h>
 #include "folder.h"
 #include "quoted-printable.h"
+#include "utils.h"
 
-typedef struct _Answer Answer;
-
-struct _Answer {
-	gchar *attendee;
-	gchar *name;
-	enum icalparameter_partstat answer;
-	enum icalparameter_cutype cutype;
-};
-
-static Answer *answer_new(const gchar *attendee, 
+Answer *answer_new(const gchar *attendee, 
 			  const gchar *name,
 			  enum icalparameter_partstat ans,
 			  enum icalparameter_cutype cutype)
@@ -77,7 +69,7 @@ static GSList *answer_find(VCalEvent *event, Answer *answer)
 	GSList *cur = event->answers;
 	while (cur && cur->data) {
 		Answer *b = (Answer *)cur->data;
-		if (!strcmp(b->attendee, answer->attendee))
+		if (!strcasecmp(b->attendee, answer->attendee))
 			return cur;
 		cur = cur->next;
 	}
@@ -90,9 +82,10 @@ void vcal_manager_copy_attendees(VCalEvent *src, VCalEvent *dest)
 	while (cur && cur->data) {
 		Answer *a = (Answer *)cur->data;
 		Answer *b = answer_new(a->attendee, a->name, a->answer, a->cutype);
-		dest->answers = g_slist_append(dest->answers, b);
+		dest->answers = g_slist_prepend(dest->answers, b);
 		cur = cur->next;
 	}
+	dest->answers = g_slist_reverse(dest->answers);
 }
 
 gchar *vcal_manager_answer_get_text(enum icalparameter_partstat ans) 
@@ -180,9 +173,10 @@ GSList *vcal_manager_get_answers_emails(VCalEvent *event)
 	GSList *cur = event->answers;
 	while (cur && cur->data) {
 		Answer *b = (Answer *)cur->data;
-		new = g_slist_append(new, b->attendee);
+		new = g_slist_prepend(new, b->attendee);
 		cur = cur->next;
 	}
+	new = g_slist_reverse(new);
 	return new;	
 }
 
@@ -295,20 +289,17 @@ gchar *vcal_manager_event_dump(VCalEvent *event, gboolean is_reply, gboolean is_
 	gchar *organizer = g_strdup_printf("MAILTO:%s", event->organizer);
 	PrefsAccount *account = vcal_manager_get_account_from_event(event);
 	gchar *attendee  = NULL;
-	gchar *body, *headers, *qpbody;
+	gchar *body, *headers;
 	gchar *tmpfile = NULL;
 	icalcomponent *calendar, *ievent, *timezone, *tzc;
-	struct icalperiodtype rtime;
 	icalproperty *attprop;
 	icalproperty *orgprop;
-	icalparameter *param = NULL;
 	enum icalparameter_partstat status = ICAL_PARTSTAT_NEEDSACTION;
-	int i = 0;
 	gchar *sanitized_uid = g_strdup(event->uid);
 	
 	subst_for_filename(sanitized_uid);
 
-	tmpfile = g_strdup_printf("%s%cevt-%d-%s", g_get_tmp_dir(),
+	tmpfile = g_strdup_printf("%s%cevt-%d-%s", get_tmp_dir(),
 				      G_DIR_SEPARATOR, getuid(), sanitized_uid);
 	g_free(sanitized_uid);
 
@@ -390,7 +381,7 @@ gchar *vcal_manager_event_dump(VCalEvent *event, gboolean is_reply, gboolean is_
 		icalproperty_vanew_dtstart((icaltime_from_string(event->dtstart)), 0));
 	icalcomponent_add_property(ievent,
 		icalproperty_vanew_dtend((icaltime_from_string(event->dtend)), 0));
-	if (event->recur && strlen(event->recur)) {
+	if (event->recur && *(event->recur)) {
 		icalcomponent_add_property(ievent,
 			icalproperty_vanew_rrule((icalrecurrencetype_from_string(event->recur)), 0));
 	}
@@ -422,7 +413,7 @@ gchar *vcal_manager_event_dump(VCalEvent *event, gboolean is_reply, gboolean is_
 
         icalcomponent_add_component(calendar, ievent);
 
-	if (event->url && strlen(event->url)) {
+	if (event->url && *(event->url)) {
 		attprop = icalproperty_new_url(event->url);
         	icalcomponent_add_property(ievent, attprop);
 	}
@@ -472,6 +463,7 @@ gchar *vcal_manager_event_dump(VCalEvent *event, gboolean is_reply, gboolean is_
 		g_free(attendee);
 		return NULL;
 	}
+
 	headers = write_headers(account, event, is_pseudo_event, is_reply, is_pseudo_event);
 
 	if (!headers) {
@@ -486,7 +478,11 @@ gchar *vcal_manager_event_dump(VCalEvent *event, gboolean is_reply, gboolean is_
 			       "\n"
 			       "%s", headers, icalcomponent_as_ical_string(calendar));
 	
-	str_write_to_file(body, tmpfile); 
+	if (str_write_to_file(body, tmpfile) < 0) {
+		g_free(tmpfile);
+		tmpfile = NULL;
+	}
+
 	chmod(tmpfile, S_IRUSR|S_IWUSR);
 
 	g_free(body);
@@ -495,6 +491,8 @@ gchar *vcal_manager_event_dump(VCalEvent *event, gboolean is_reply, gboolean is_
 	g_free(attendee);
 	g_free(organizer);
 	
+	tzset();
+
 	return tmpfile;	
 }
 
@@ -576,7 +574,7 @@ gchar *vcal_manager_dateevent_dump(const gchar *uid, FolderItem *item)
 	
 	subst_for_filename(sanitized_uid);
 	
-	tmpfile = g_strdup_printf("%s%cevt-%d-%s", g_get_tmp_dir(),
+	tmpfile = g_strdup_printf("%s%cevt-%d-%s", get_tmp_dir(),
 				   G_DIR_SEPARATOR, getuid(), sanitized_uid);
 	g_free(sanitized_uid);
 
@@ -606,7 +604,10 @@ gchar *vcal_manager_dateevent_dump(const gchar *uid, FolderItem *item)
 			       "\n"
 			       "%s", headers, lines);
 	g_free(lines);
-	str_write_to_file(body, tmpfile); 
+	if (str_write_to_file(body, tmpfile) < 0) {
+		g_free(tmpfile);
+		tmpfile = NULL;
+	}
 	chmod(tmpfile, S_IRUSR|S_IWUSR);
 
 	g_free(body);
@@ -626,12 +627,8 @@ gchar *vcal_manager_icalevent_dump(icalcomponent *event, gchar *orga, icalcompon
 	gchar **lines = NULL;
 	gchar *tmpfile = NULL;
 	icalcomponent *calendar;
-	icalproperty *attprop, *prop;
-	icalproperty *orgprop;
-	icalparameter *param = NULL;
+	icalproperty *prop;
 	icalcomponent *ievent = NULL;
-	
-	enum icalparameter_partstat status = ICAL_PARTSTAT_NONE;
 	int i = 0;
 
 	ievent = icalcomponent_new_clone(event);
@@ -642,12 +639,12 @@ gchar *vcal_manager_icalevent_dump(icalcomponent *event, gchar *orga, icalcompon
 
 		subst_for_filename(sanitized_uid);
 
-		tmpfile = g_strdup_printf("%s%cevt-%d-%s", g_get_tmp_dir(),
+		tmpfile = g_strdup_printf("%s%cevt-%d-%s", get_tmp_dir(),
 					      G_DIR_SEPARATOR, getuid(), sanitized_uid);
 		g_free(sanitized_uid);
 		icalproperty_free(prop);
 	} else {
-		tmpfile = g_strdup_printf("%s%cevt-%d-%p", g_get_tmp_dir(),
+		tmpfile = g_strdup_printf("%s%cevt-%d-%p", get_tmp_dir(),
 				      G_DIR_SEPARATOR, getuid(), ievent);
 	}
 
@@ -720,7 +717,10 @@ gchar *vcal_manager_icalevent_dump(icalcomponent *event, gchar *orga, icalcompon
 			       "\n"
 			       "%s", headers, qpbody);
 	
-	str_write_to_file(body, tmpfile); 
+	if (str_write_to_file(body, tmpfile) < 0) {
+		g_free(tmpfile);
+		tmpfile = NULL;
+	}
 	chmod(tmpfile, S_IRUSR|S_IWUSR);
 
 	g_strfreev(lines);
@@ -752,16 +752,17 @@ VCalEvent * vcal_manager_new_event	(const gchar 	*uid,
 	event->organizer 	= g_strdup(organizer?organizer:"");
 	event->orgname	 	= g_strdup(orgname?orgname:"");
 
-	if (dtend && strlen(dtend)) {
+	if (dtend && *(dtend)) {
 		time_t tmp = icaltime_as_timet((icaltime_from_string(dtend)));
 		gchar buft[512];
+		tzset();
 		event->end	= g_strdup(ctime_r(&tmp, buft));
 	}
 	
-	if (dtstart && strlen(dtstart)) {
+	if (dtstart && *(dtstart)) {
 		time_t tmp = icaltime_as_timet((icaltime_from_string(dtstart)));
-		time_t tmp_utc = icaltime_as_timet((icaltime_from_string(dtstart)));
 		gchar buft[512];
+		tzset();
 		event->start	= g_strdup(ctime_r(&tmp, buft));
 	}
 	event->dtstart		= g_strdup(dtstart?dtstart:"");
@@ -836,9 +837,9 @@ PrefsAccount *vcal_manager_get_account_from_event(VCalEvent *event)
 	/* find an attendee corresponding to one of our accounts */
 	while (cur && cur->data) {
 		gchar *email = (gchar *)cur->data;
-		if (account_find_from_address(email)) {
+		if (account_find_from_address(email, FALSE)) {
 			g_slist_free(list);
-			return account_find_from_address(email);
+			return account_find_from_address(email, FALSE);
 		}
 		cur = cur->next;
 	}
@@ -888,7 +889,7 @@ void vcal_manager_save_event (VCalEvent *event, gboolean export_after)
 	xml_tag_add_attr(tag, xml_attr_new("postponed", tmp));
 	g_free(tmp);
 	
-	tmp = g_strdup_printf("%lu", event->rec_occurence);
+	tmp = g_strdup_printf("%d", event->rec_occurence);
 	xml_tag_add_attr(tag, xml_attr_new("rec_occurence", tmp));
 	g_free(tmp);
 	
@@ -935,7 +936,7 @@ void vcal_manager_save_event (VCalEvent *event, gboolean export_after)
 	}
  
  	if (export_after)
-		vcal_folder_export();
+		vcal_folder_export(NULL);
 }
 
 static VCalEvent *event_get_from_xml (const gchar *uid, GNode *node)
@@ -1038,11 +1039,12 @@ static VCalEvent *event_get_from_xml (const gchar *uid, GNode *node)
 				cutype = atoi(attr->value);
 		}
 
-		event->answers = g_slist_append(event->answers, answer_new(attendee, name, answer, cutype));
+		event->answers = g_slist_prepend(event->answers, answer_new(attendee, name, answer, cutype));
 		g_free(attendee);
 		g_free(name);
 		node = node->next;
 	}
+	event->answers = g_slist_reverse(event->answers);
 	
 	return event;
 }
@@ -1127,7 +1129,7 @@ static gchar *write_headers(PrefsAccount 	*account,
 	gchar *attendees = NULL;
 	enum icalparameter_partstat status;
 	gchar *prefix = NULL;
-	gchar enc_subject[512], enc_prefix[512], enc_from[512], *from = NULL;
+	gchar enc_subject[512], enc_from[512], *from = NULL;
 	gchar msgid[128];	
 	gchar *calmsgid = NULL;
 
@@ -1135,9 +1137,7 @@ static gchar *write_headers(PrefsAccount 	*account,
 	
 	if (is_pseudo_display) {
 		struct icaltimetype itt = (icaltime_from_string(event->dtstart));
-		struct icaltimetype itt_utc = (icaltime_from_string(event->dtstart));
 		time_t t = icaltime_as_timet(itt);
-		time_t t_utc = icaltime_as_timet(itt_utc);
 		get_rfc822_date_from_time_t(date, sizeof(date), t);
 	} else {
 		get_rfc822_date(date, sizeof(date));
@@ -1154,7 +1154,7 @@ static gchar *write_headers(PrefsAccount 	*account,
 			gchar *tmp = NULL;
 			Answer *a = (Answer *)cur->data;
 			
-			if (strcmp(a->attendee, event->organizer)) {
+			if (strcasecmp(a->attendee, event->organizer)) {
 				if (attendees) {
 					tmp = g_strdup_printf("%s>,\n <%s", attendees, a->attendee);
 					g_free(attendees);
@@ -1216,7 +1216,19 @@ static gchar *write_headers(PrefsAccount 	*account,
 		calmsgid = g_strdup("");
 	}
 
+	if (account && account->set_domain && account->domain) {
+		g_snprintf(msgid, sizeof(msgid), "%s", account->domain); 
+	} else if (!strncmp(get_domain_name(), "localhost", strlen("localhost"))) {
+		g_snprintf(msgid, sizeof(msgid), "%s", 
+			strchr(account->address, '@') ?
+				strchr(account->address, '@')+1 :
+				account->address);
+	} else {
+		g_snprintf(msgid, sizeof(msgid), "%s", "");
+	}
+
 	generate_msgid(msgid, sizeof(msgid));
+
 	result = g_strdup_printf("%s"
 				"From: %s <%s>\n"
 				"To: <%s>\n"
@@ -1258,7 +1270,6 @@ static gchar *write_headers_ical(PrefsAccount 	*account,
 	gchar date[128];
 	gchar *result = NULL;
 	gchar *method_str = NULL;
-	gchar *attendees = NULL;
 	gchar *summary = NULL;
 	gchar *organizer = NULL;
 	gchar *orgname = NULL;
@@ -1385,7 +1396,7 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 				folder_item_remove_msg(folderitem, msgnum);
 			folder_item_scan(folderitem);
 		} else if (err) {
-			alertpanel_error_log(err);
+			alertpanel_error_log("%s", err);
 			g_free(err);
 		}
 	}
@@ -1397,7 +1408,7 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 	if (folder)
 		folder_item_scan(folder->inbox);
 
-	vcalviewer_reload();
+	vcalviewer_reload(folder->inbox);
 	return TRUE;
 }
 
@@ -1443,7 +1454,7 @@ EventTime event_to_today(VCalEvent *event, time_t t)
 			return EVENT_TOMORROW;
 		} else if (days > 1 && days < 7) {
 			return EVENT_THISWEEK;
-		} else if (days >= 7) {
+		} else {
 			return EVENT_LATER;
 		}
 	} else if (today.tm_year > evtstart.tm_year) {
