@@ -36,6 +36,7 @@
 #include "vcal_manager.h"
 #include "vcal_meeting_gtk.h"
 #include "vcal_prefs.h"
+#include "common-views.h"
 #include "mainwindow.h"
 #include "prefs_account.h"
 #include "account.h"
@@ -52,7 +53,7 @@ struct _VCalMeeting
 	gint       sequence;
 	gint 	   method;
 	GtkWidget *window;
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	GtkWidget *table;
 #else
 	GtkWidget *table1;
@@ -99,7 +100,7 @@ static GdkCursor *watch_cursor = NULL;
 
 VCalAttendee *attendee_add(VCalMeeting *meet, gchar *address, gchar *name, gchar *partstat, gchar *cutype, gboolean first);
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 #define TABLE_ADD_LINE(label_text, widget, do_space) {				\
 	gchar *tmpstr = g_strdup_printf("<span weight=\"bold\">%s</span>",	\
 				label_text?label_text:"");			\
@@ -214,26 +215,6 @@ static gboolean avail_btn_can_be_sensitive(void)
 		return TRUE;
 }
 
-static gchar *get_month_name(gint i)
-{
-	struct tm *lt;
-	time_t t;
-	gchar day[4], mon[4];
-	gint dd, hh, mm, ss, yyyy;
-	struct tm buft;
-	
-	tzset();
-	
-	t = time(NULL);
-	lt = localtime_r(&t, &buft);
-	lt->tm_mon = i;
-	
-	sscanf(asctime(lt), "%3s %3s %d %d:%d:%d %d\n",
-	       day, mon, &dd, &hh, &mm, &ss, &yyyy);
-	
-	return g_strdup(mon);
-}
-
 static gint get_dtdate(const gchar *str, gint field)
 {
 	time_t t = icaltime_as_timet((icaltime_from_string(str)));
@@ -351,7 +332,7 @@ VCalAttendee *attendee_add(VCalMeeting *meet, gchar *address, gchar *name, gchar
 	gtk_box_pack_start(GTK_BOX(att_hbox), attendee->remove_btn, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(meet->attendees_vbox), att_hbox, FALSE, FALSE, 0);
 	address_completion_register_entry(GTK_ENTRY(attendee->address), FALSE);
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	gtk_widget_set_size_request(attendee->address, 320, -1);
 #else
 	gtk_widget_set_size_request(attendee->address, 220, -1);
@@ -961,7 +942,6 @@ static gboolean check_attendees_availability(VCalMeeting *meet, gboolean tell_if
 	gchar *real_url = NULL;
 	gint num_format = 0;
 	gchar *change_user = NULL, *change_dom = NULL;
-	gchar *problems = NULL;
 	gchar *dtstart = NULL;
 	gchar *dtend = NULL;
 	gboolean find_avail = FALSE;
@@ -1315,6 +1295,7 @@ static gboolean send_meeting_cb(GtkButton *widget, gpointer data)
 	if (folder && redisp) {
 		MainWindow *mainwin = mainwindow_get_mainwindow();
 		summary_show(mainwin->summaryview, folder->inbox);
+		vcal_folder_refresh_cal(folder->inbox);
 	}
 
 	return res;
@@ -1337,15 +1318,17 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 {
 	VCalMeeting *meet = g_new0(VCalMeeting, 1);
 	GtkTextBuffer *buffer = NULL;
-	GtkWidget *date_hbox, *date_vbox, *save_hbox, *label, *vbox, *hbox;
+	GtkWidget *date_hbox, *date_vbox, *save_hbox, *label, *hbox;
 	gchar *s = NULL;
 	GtkObject *start_h_adj, *start_m_adj, *end_h_adj, *end_m_adj;
 	int i = 0, num = 0;
 	GtkWidget *scrolledwin;
 	GList *times = NULL;
 	GList *accounts;
+#ifdef GENERIC_UMPC
 	GtkWidget *notebook;
 	GtkWidget *maemo_vbox0;
+#endif
 	
 	if (!watch_cursor)
 		watch_cursor = gdk_cursor_new(GDK_WATCH);
@@ -1358,7 +1341,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 	end_m_adj   = gtk_adjustment_new (0, 0, 59, 1, 10, 10);
 
 	meet->window 		= gtkut_window_new(GTK_WINDOW_TOPLEVEL, "vcal_meeting_gtk");
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	meet->table  		= gtk_table_new(7, 2, FALSE);
 #else
 	meet->table1  		= gtk_table_new(4, 2, FALSE);
@@ -1518,7 +1501,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 			 G_CALLBACK(meeting_end_changed),
 			 meet);
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	gtk_widget_set_size_request(meet->start_time, 80, -1);
 	gtk_widget_set_size_request(meet->end_time, 80, -1);
 #else
@@ -1541,7 +1524,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 	gtk_box_pack_start(GTK_BOX(date_vbox), meet->start_c, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(date_hbox), date_vbox, FALSE, FALSE, 0);
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	label = gtk_label_new(" "); 
 #else
 	label = gtk_label_new(""); 
@@ -1644,7 +1627,7 @@ static VCalMeeting *vcal_meeting_create_real(VCalEvent *event, gboolean visible)
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(meet->avail_evtbox), FALSE);
 	gtk_container_add (GTK_CONTAINER(meet->avail_evtbox), meet->avail_img);
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	TABLE_ADD_LINE(_("Organizer:"), hbox, FALSE);
 	TABLE_ADD_LINE(_("Summary:"), meet->summary, TRUE);
 	TABLE_ADD_LINE(_("Time:"), date_hbox, TRUE);
@@ -1702,6 +1685,46 @@ VCalMeeting *vcal_meeting_create(VCalEvent *event)
 	return vcal_meeting_create_real(event, TRUE);
 }
 
+VCalMeeting *vcal_meeting_create_with_start(VCalEvent *event, struct tm *sdate)
+{
+	VCalMeeting *meet = vcal_meeting_create(event);
+	int num = -1;
+	gtk_calendar_select_day(GTK_CALENDAR(meet->start_c),
+				sdate->tm_mday);
+	gtk_calendar_select_day(GTK_CALENDAR(meet->end_c),
+				sdate->tm_mday);
+
+	gtk_calendar_select_month(GTK_CALENDAR(meet->start_c),
+				sdate->tm_mon, sdate->tm_year+1900);
+	gtk_calendar_select_month(GTK_CALENDAR(meet->end_c),
+				sdate->tm_mon, sdate->tm_year+1900);
+
+	if (sdate->tm_hour != 0) {
+		num = get_list_item_num(sdate->tm_hour, 0);
+		if (num > -1)
+			gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->start_time)->list), num);
+		if (sdate->tm_hour < 23) {
+			num = get_list_item_num(sdate->tm_hour+1, 0);
+			if (num > -1)
+				gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->end_time)->list), num);
+		} else {
+			struct tm tm_tomorrow;
+			tm_tomorrow.tm_mday = sdate->tm_mday;
+			tm_tomorrow.tm_mon = sdate->tm_mon;
+			tm_tomorrow.tm_wday = sdate->tm_wday;
+			tm_tomorrow.tm_year = sdate->tm_year+1900;
+			tm_tomorrow.tm_hour = sdate->tm_hour;
+			orage_move_day(&tm_tomorrow, +1);
+			gtk_calendar_select_day(GTK_CALENDAR(meet->end_c),
+						tm_tomorrow.tm_mday);
+			gtk_calendar_select_month(GTK_CALENDAR(meet->end_c),
+						tm_tomorrow.tm_mon, tm_tomorrow.tm_year);
+			gtk_list_select_item(GTK_LIST(GTK_COMBO(meet->end_time)->list), 0);
+		}
+	}
+	return meet;
+}
+
 VCalMeeting *vcal_meeting_create_hidden(VCalEvent *event)
 {
 	return vcal_meeting_create_real(event, FALSE);
@@ -1712,21 +1735,9 @@ gboolean vcal_meeting_send(VCalMeeting *meet)
 	return send_meeting_cb(NULL, meet);
 }
 
-static gboolean g_slist_find_string(GSList *list, const gchar * str)
-{
-	GSList *cur = list;
-	while (cur) {
-		if (!strcmp((gchar *)cur->data, str))
-			return TRUE;
-		cur = cur->next;
-	}
-	return FALSE;
-}
-
 gint vcal_meeting_alert_check(gpointer data)
 {
 	GSList *events = NULL, *cur = NULL;
-	static GSList *alert_done = NULL;
 
 	if (!vcalprefs.alert_enable)
 		return TRUE;
@@ -2040,7 +2051,6 @@ gboolean vcal_meeting_export_freebusy(const gchar *path, const gchar *user,
 	time_t whole_start = time(NULL);
 	time_t whole_end = whole_start + (60*60*24*365);
 	gboolean res = TRUE;
-	GSList *busy_spots = NULL;
 	struct icaltimetype itt_start, itt_end;
 	long filesize = 0;
 	
@@ -2132,7 +2142,6 @@ gboolean vcal_meeting_export_freebusy(const gchar *path, const gchar *user,
 	icalcomponent_free(calendar);
 	g_slist_free(list);
 	
-putfile:
 	if ((!path || strlen(path) == 0 || !vcalprefs.export_freebusy_enable)) {
 		g_free(tmpfile);
 		return TRUE;
