@@ -26,13 +26,16 @@
 
 #include <glib.h>
 
+#include "mainwindow.h"
 #include "prefs.h"
 #include "prefs_gtk.h"
 #include "prefswindow.h"
 #include "gettext.h"
 #include "common/utils.h"
 
+#include "vcalendar.h"
 #include "vcal_prefs.h"
+#include "vcal_folder.h"
 
 #define PREFS_BLOCK_NAME "VCalendar"
 
@@ -553,11 +556,31 @@ static void vcal_prefs_destroy_widget_func(PrefsPage *_page)
 {
 }
 
+void vcal_prefs_save(void)
+{
+	PrefFile *pfile;
+	gchar *rcpath;
+	rcpath = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, COMMON_RC, NULL);
+	pfile = prefs_write_open(rcpath);
+	g_free(rcpath);
+	if (!pfile || (prefs_set_block_label(pfile, PREFS_BLOCK_NAME) < 0))
+		return;
+
+	if (prefs_write_param(param, pfile->fp) < 0) {
+		g_warning("failed to write Vcalendar configuration to file\n");
+		prefs_file_close_revert(pfile);
+		return;
+	}
+        if (fprintf(pfile->fp, "\n") < 0) {
+		FILE_OP_ERROR(rcpath, "fprintf");
+		prefs_file_close_revert(pfile);
+	} else
+	        prefs_file_close(pfile);
+}
+
 static void vcal_prefs_save_func(PrefsPage * _page)
 {
 	struct VcalendarPage *page = (struct VcalendarPage *) _page;
-	PrefFile *pfile;
-	gchar *rcpath;
 
 /* alert */
 	vcalprefs.alert_enable =
@@ -618,23 +641,7 @@ static void vcal_prefs_save_func(PrefsPage * _page)
 	    gtk_editable_get_chars(GTK_EDITABLE(page->freebusy_get_url_entry), 0, -1);
 
 
-	rcpath = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, COMMON_RC, NULL);
-	pfile = prefs_write_open(rcpath);
-	g_free(rcpath);
-	if (!pfile || (prefs_set_block_label(pfile, PREFS_BLOCK_NAME) < 0))
-		return;
-
-	if (prefs_write_param(param, pfile->fp) < 0) {
-		g_warning("failed to write Vcalendar configuration to file\n");
-		prefs_file_close_revert(pfile);
-		return;
-	}
-        if (fprintf(pfile->fp, "\n") < 0) {
-		FILE_OP_ERROR(rcpath, "fprintf");
-		prefs_file_close_revert(pfile);
-	} else
-	        prefs_file_close(pfile);
-	
+	vcal_prefs_save();
 	vcal_folder_export(NULL);
 }
 
